
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python Fintech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x0b\x00\x00\x00@\x00\x00\x00s6\x00\x00\x00y\x08\x00e\x00\x00\x01Wn\x14\x00\x01\x01\x01e\x01\x00d\x00\x00\x83\x01\x00\x82\x01\x00Yn\x01\x00Xe\x00\x00e\x02\x00e'
        b'\x03\x00d\x01\x00d\x02\x00\x83\x04\x00\x01d\x03\x00S)\x04z\x1afintech package not loadeds\xda2\x00\x00PYARMOR\x00\x00\x03\x05\x00\x17'
        b'\r\r\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x9a2\x00\x00\x00\x00\x00\x00v6\xca\xf9\x1a\xe7\x91\x9ey\x1b\xaa?\x19n\xc1\xd5\x00\x00\x00\x00\x00\x00\x00\x00\xe5\xfc\xe5\xc6c\x91\x87O\x14LJ\xd7\xe9'
        b'\x1com\xecFN\x14\xd9"\x1b%vg\x83\x8c\x92\xd8\xc7\xfdF7\x02K&\x9a\x1e\x8e\x15\xd2\x85F\xb4\xad\x84\x8e\xb7\x0et\xa5\x1b\xf6\x99\xe3\xc3P\xac\xfe\xb19\xd0\xe3y\xa0\xaf*\x18dL\xdc\x10\x95\xdd\x06\x94'
        b'\xa3?\x04\xfaP\xfd\xdc58\x1fD\xb2Z\xf9\x95\xa2\xf36\xa6\x9b4\x8b\x10_M\xc6\x9erN\xb6\xfb\xbb\xbc\xf5\xd1\xca_\xc2iv\xf0NU\xeb\x85\xaf\x8bDx\x99\x88X\x14j%jF\xf2\xea\xfb\xf8\xb4\x0b\xc7'
        b'\xab{8\xbb*\xd0\xf5\x93._O\xc6~\xee\xb30\xfa\xebba\xbb\x8d\x92\xe6\x90\x17=\x9fe\x85\x8ckt\x99D\xb0D\xa6c\xc3\x86\xe3\xff\xa9R\xf2\x11\xce\x90\xeb\x8c\x10#y\xdf6{\xf6\xad\xa1\xe77\x04m'
        b'\xd1\x02\xb2\xe2\xbd\x05\xab;\x94=A\xa4\xd0\xf3vFM\xfb\xb7\xfd\x9e`w\xc1\x1e\xa1\x8b\xf3D\xf8\xff\x8c6\xd1\xbf6+\x9bA\xed\xe5\xf4r\x8e\xfa#\xf5jSU\xd6\x1c\xcbTA"\xd4t\x13\xd5>Y;4'
        b"\xd2\x94\xe8\x8c\xe4,\x89\x8a\xb9\xadeu\xd8\x7fr\x8f\x00\x8e\xb3|\xd8\xb6\x82\xef\xe4'9\x94\xfe\xee\xb5M\t\x04\x96\xf3\xe4\xf1\x02\x89\xdd/\xedm\xe4\xc0 \x89\x11\xed\xc6\x08\x8a\x84a\x11\xa5\x19~\xc9\xd0c\x88w"
        b'\x82a\x04l=8\xdf\x12y\xe9\xee\xfciY#\xe2\'\x1bk\x87\xc3\xd6\xe1\xb2\xa6?mB\t\x8e\x11\x05}E}\t\xcd\xac\xc15\x87j\xdf\xda\xc0J"\xea8\xb3\x02b\xb1>:6\x0e.\x11<\x8a\xc8\xf3\xfa'
        b"\x8b\xb3>G\xab\x0c\xd8\xb3\xca\xec\xe8\xf3\x073\xa3(u\xa6c\x99\x7f\x14\x8c\nsG'\xf86\xf5\xda\x8e\x9a\xcea\xfff\x15\xa4\x94f|o\xa6\xaf\x9a/\xb6\x7f\xc4\xd6\x1bnP3h\x7f\x94\x0b4\x0c\xc5:\xf0"
        b'\xff\x9a\xb0\x02Y\x98J@p\x08\xf6\x1fW\x01}\xa7\xb5;\xc1\xccB\xd5ZZ>\xdaO\xfd\xf8p\xfa\x8e\xd2\xc8\x06\xac:\xe1\x03\xc8\xbdT\xae"_\xcaS+\xaa\x1b\x0e{\n\xa9\xa9\x87B\xfa+\x81}\xcc\xd9\xef'
        b'\xc7J\xbc\xb0\x91\xc0\xcb\xca\xd5\xef\t\x11H\xe2dZb\r\x11a7J\xcbP\xb2\xe4C\x92\x8d\xbef\xdd\xbc\xd2\xd5)#(\t\xe2\xf0UI^\x90\x89\x028j\xc2Ea\xfcZ\xe8"\x1d\xe1\xf9K8\xebyV'
        b'\xfd)\x10\x14\x1bl\x07\xb6"fPG\xeb\x13AM3q\x96\x11\xef\xb8+l\xdf\xd9\xa3`\xd5 \x96\xe7b\xe6\xaa9S\xd4\x0c\xbc\xf0\x1a\x1f@,\xac\x04\x01\x9b\xbb;[\x95\xe6\x97\xeaPX^\xb4\\\x9biv'
        b"\x0e\xcb\xb0\xa1\x98n45\x15\x0e\x95\x8a-\x9a\x1dA\x02\x16\xd1\tFZ\xd2\xe1J\xcc\x92\xe8\xb7\xd7b\x0bk'\xcc\xc2\xdf\xf5\xbe\xdc\x93\x92e\x8f9*fv\xdf\x86\xe7%\x9f\xb8\xe2\x8c\xfd`\x8f\xee\xd6%/\xf8"
        b'\xe4A\xbfy\xb9.\xdd\\\xb1\x90~wb\xfeL\x9f\xea\xe2C\x1f\x95\xc1\xdb?\xd0\xf7\xbdBX\x11\x95&G\xcf\x1e\x8f\xff\t9\xfd}9\x14W\x11\xc7g9\xf0\xebqV\xcc\x1b\xe3\xefu\x96\x9e$a[\xfa\xa6'
        b')\xe1\xa4\xb9\x10\x16\xbd<5\xc84\x11\xfe~\x81F\x93\xf0\xfeDf.\xf7\xbf\x9eN%\xb2\xa4\xc8,/A\x94\x96\x1c\x01L|\xdai\xee\xc4\xae\x93\x15OB\xb4\xffH\x0e\x0c\xa4\xe2JP\x04\x90v\x94\x98\xdd\xe7'
        b'MgdG;\x9e\xe1\x00\xcdL\x17\xf8\x0bBL\xb4^\x93=\x9f\x07\xfb\x01\xcb\xc8l\xb0\x00%3<^\x7f3\xb5|\x81\x99O\xd0\xfb\xde\x98\xc1\x05\x01_N\xf0\xf5j\x9a\xba\xaa\xf3\x96\x05&\x02z\x1c\xc6\xf8-'
        b'r\t \xe9\xbb\xdc#\x8d\x85\xb2 \x9c\x0e\x99r\xeb\x9c\x848\xdf[Aua\xcc\x1fx\xad\x9f\xe4\xa7\xb8H\xeb\x05t\x0e\xae\x8e\xd6/{\xb5t\xcb\n\xd2\x13}\x91\x98\xae\x08\xa1\x90\x19\x0b\xf73\xc5\xf3\x05\x1e~'
        b'K1`\xc2\xa0\x90\xef\xebl\xb5\xdd\xa6\x81?Upr\xddW+Zb\xecxP\xf7\xa4\xe9\xfc|OD\xf6lu\xbe\n\xbdr\xe1\x9fZ\xe4\x82J\xeb#\xb6\xa5\x8ex\xcc\x01\x9c\xb4\xdc2\xda\x02\x14d\x1f~\xbc'
        b'\xddUlc \x01p\xd9\x1e(p\x17N\x9b\x9f\xd4\xc4u\xde\xf6\x84\xa6\x93\xaf\x82\xed\t\x1e\x05\x94\xab\x1f!G\x19\x81\xb5\xdfi\xcc?}\x0e9\xb5\xfb\xeb9\xb4\xbd\xeeHk.\xa2h\xb7\x84Q\x0c\xe1.\xc0\xea'
        b'\xfc\xc8\x10\x0f\x04e\xf9r\x88\xe0\xaf\x18\x15\xb1\r\xea0\x1b\x9b\xa8\xb2\x19\xa7n\xeb\xd6\x0e~\xab\xeeu\xa5\x8e\xad_\x9d\xc4|pGJ\xe1;U|\xfe^;R\x95\x98\x94m\x9c\r\xd4\xc0\xce~\xc5\xae\xf2\xc7\x15'
        b'\x92o;\xb0\x99\x1f7\x1b\x05\xbeM\x99\x8eT\xc4d\xdb\xa5k?\xc3Y\x0c\x9b\x04\x8c\xbeF7\xe381\x11\xb9\xb4\xf3\x9f+\xa5\x01\xb7\xe8<\xab\xbc0\x01\xd1\x1c\x8am\xf1w)\x80h\x0c7\x98BF\x18*\xc5'
        b'\x9c\xcb\xb7\xd8\x1d\xf0]\x8e\xca\x12\xeb\xc5\xde6\xca`\xf7\xd4\xe1`\x9d\x08\x04\x06q\x9bV\xe2\xbb\x1a\t\x0c\x0fn\xb1b\xd7\x95{@7\xd4\xd0\xaa$\x0c\xf5>\xb1\x16G]\x9a\x08\xaem\xc8\x01\x81\xa2\xd7\xcb(\xc4'
        b'\x1b\xe5Y\xac&k\xa0Wrd\x9dn\x1du\xe7(\xe6\xa577\xc5\x9d"\xca\xe9\x12\xcb\xb3\xca\xa9\xf6\x9b\xabF\xef\x82\xc3\x19\xa3\xea\x80\xf6r]S\xddS\x15q\xb6l\x16r\xf8W\x9fzf\xb8\xd4x)\x86a'
        b'\xf2\xc0w\x0c\x81(\x99\xe1\xc2A\xa0\xc0\x88%\xc0|"m\xbb\x1d\xba\xc6`V\xb6\xc0\x1d\x116\x93\xad\x84\x16\xd8\x14\x11\xac\x87c)Q\xfb\x943\xf8D+\xf3\xcc\xd6{)\xb2\'\x04\xd3\xabqI\x04\xf4\x0c\xc6:'
        b"\x18?\\)\xcb8\xbc\x90\x973F\xb8\xeeZ\x18\xd5c\xb2\x88\x8b\xa8\xd9\x04\xe9{w\xbc\x98'b\xfa\x81\x81d\xcf\xd6^\xafU^\x0b4\xd1\x9a\x0bAp\x13\x81\n:\xee\x8boAe\xfa\xa5p\xe9B7a^"
        b'|\x12!;\x9c\x13\xfb\xe7\xd4\xc8F\xfa\xb1\xa1\x86\xb2\x15*\xa8!"\x87\x18\x06\x03}Bm\x9d{V\x98\xa0*\n\xd9U\xf7\xfa\xf0\xd6\x8cW"\x80\x98\xbb\xbdU\xe1\xd1Ki1i\xdf\xc9\x82\xa86\x87/=\x19'
        b'\n9\xf0W\xa1T\xd8,\xb0\x18\xbb_:\xc8\x86)a\xcc\x10t\xf2\xfd8\xe7\r\xa5\x1f\xbcE\x81.d\x8d\xe0\x84]\xd2\xf4*\x87s\xe2\xd7\xd6\xd0q\xae[\x80\xff\x84Qhn0\xa9\xfe\xb5R\xf3S\x1d\x1b\x1d'
        b'/j\xf3R\x9b7\x1a%\x18fCy\x8e\xb73\x1d\x93\xdf\xef\xa6\xc7:[\x12\xe9\xd0\x0c\x82\x80\xc3\xf1\x14Y(_;\xfa\xe8\xab\xe1\x01\\G\xde(#,U5k\x06\xf6}\x96\xdePG\xac\xeb\xf74\xed:\xb8'
        b'\xd2\xf9Og2\xd3\x13\x95E`\x05\x8bGRo\xe8aJ\xa91\x85nJ\xf6\xa8\x1a;\xc3\xc6Br\x11\x03\xcb\xa1\xd5\x17\x8a\xbd\xb9Mx\xb2Fu|\xc3\x91\x13L\x9a\xdd\xab\xd4\xe9%\x9e|\xf2n\xf9\x9b\xa8\xb9'
        b'\x05\xf5T\xe6M\x08\xa6\xbb\x1a\xbb\xef\t\x08(\xfa|\xc3\x18)\xb1\x05\x9d1\xb27\xa4\xc8\xf3\xe8f\x9d{\xcb\x064T\x87\xbf\xe6\xfe\x9b\x97-E\xe1M\xad\x99\xa7\x81\x8by\xdb\x93t\xa0@\x85\xdd\xeeZ\x81\x83.'
        b'\xc1v\xf6\n\x1ey\xac\xfb\xd2i\xed\x15\xfes\x9b\x10O\xf29\x12\x9b\x84E\xd0\xb7yV\x00\x8fi8\xa9\xf1VJn\x8f\xdb\x13\x9c\x8fc\xecx\xcb,\x03\xed\x9dI\xbe\x06\x8e\xf7k*d\xd7\xea\xb1\xa8\xe5\xd7v'
        b'\xf0\x0b4;\xca*PK\x86\xc50\x97\xb8\x8ag\xc8\x08\xb2B\x08ss\x1c\x08\xc2\\\xe8\x93\x02\xc4/$\xc6\xbb\x8a\x930\x10\x0f\xe5\xf2\xcf\x9ae\xf3\xce\x0b\x96;c\x1f\xf1~1\x03\xa5drQ\x18\xac\xae#\x0b'
        b'\xbc\x0e\x991s\xe7\xb5B\xe0\xb4\xa0\xef!vS\xbe\xf76\x80\x12\x96q\xc6\xef\x07KWT\xdc3\xee\xadS\xe2\xa7|~Ha\xa1\xf9\xb9f\xa0\xfe\xbc\xc8\xc5(2Xd\xc3@1uXhH\xd8\xc0\x93-\xc6'
        b'\xf1_U\x00\x9c\xe1\xd4\x94\x8c\x91\x05\xa8\xcf\x1dH\xe8\x9fi\x8f\x1fP\x87\x87"\x84.B\xbfa\x94b\x89\x9a\x90\xefK6\xb4\x0f0\x1d\x0c\xce\xea\x00\x84_\xe5\xa7\xbdd\x86\xe2\x9c_\xd0\xaa\x11SL\xb8Q1#'
        b'5A\xba,\xa9\x9as\x1e\x87\xc3\xa1\xabw\xa0s\x15\xc2x\xa1\x0e\x840\xd6\x1a]N!\x9a\xed\xb1\xd7\xc6 \xc3b\x81\x00J\x929\xc5\x88s\xe9\xbc\xc8\xa9~\xde\xc7\xf4~\x1d\xdf\x9f%\x06\x82\xf5\x80g\x15K\x14'
        b"\x08'\x07\x81s\xbdSL\xc5<\xec\xb8\xa4\xe9.\xb53\xa5\x0f\xbfZ/\xac\x07M\xebbL\xac\x17?H\x13\xf8\xb1H{\xbc\xcf&l\x16\x9b\x82!.\xac\xf6\x10\xe1\xf9\x9d\xd2\xf6M\x88\x13\x95\xf4\xfa\x86n\x07m"
        b"\xa8\xf4\xe4\xbe?^*\xcf\xd5\x14U\x1d\xc0\xa7\x9f=\x95,\xc7=90\xe8bGL\xccZ\xe2'\r\x14\xc0R>\xe9\xfb\xb9c\x8ae\x80\x84\x88\x8c\x1f\x90\x96\xf8\xbc\x1c|\xbd\xe9H\x98\xee\xefP\x98\x8b\x9d\xf5\x16"
        b'\xc8\xe3\x04\xf8+\xb4\xdcd \xf9\x08\x06c\x84\xdc\x18bk^\x7f?\'>\x91\x1d\t\xa1}]~q\xa8f\x8d\x89\xabj\x8d\xad~:\x0bY\xa3\x95z\xa5\xd7|\xb2"\x00|n\xb8\xaf\xa9G>\xceP\x97c\xdf'
        b"!\xad\xb0M\x1c\x99CKXR\xa4\x80\xd6k\xee['i\xec#'\x16\xbb\x96\xd6ww\xbe]5\xeei\xa5XIf\x02\xc6\xd2\x93\xf0\xd0.\x04\xa8Mm'\x81\xd4q\xceO>\xb5\r2\xb1\x8a\x03\xba\xe4#\x9e"
        b")\xf2\x14M\x1d\xd4\x9d;S\xb3\xa9\xf9m\xb1\xe5\xc9\x8c\xc7\x8f$*d$=@\x0c32!du\n\xca\x7f$sR [\xa5^\x8f\x84\x07H\x97\xa2'\xc1<O\xc7:v\x9beG~\xd57\xe9\x95\xaeo"
        b" \xdeo\xcf\xae\x98\xb3\xa9\xda\x0e\xa6'\x9d\xc4\xc6\x98$\x96\xfb.\xa5\x08b!%!\xa8\xb2\x89\x90\xea\x97Vu\xd9\x88\xff7\x9a^D\xc4\xfd\x0c\x86\xed\x98\xbd\xf3&\t\x95dX\x0cVD\x98\xe0\xa7\x9a\x03\x8a:"
        b'\xa4Fm(h\xc05\xed\x18\xea\x8fb\xf3\xb2\xb0\xb9E~\x99 \xef\xb4s\xb5\xadK|\x82.\x89\xb2\x15\x9f`\xe0\xe5-\xe2\x14\xe9\xf0\xb8G\x016#\xcd\x1aG\xe2\xa9\xe7&q4\xa1\xca\xb8\xea\xdb/\x86\x960'
        b'\xd7U\xcd\xbd\x15\xabGW\xa5\x85\x8b\t\xe4mc$\xb9r>\xd6\x8b87Q\x11\xdd\xd9\xfc\x14\xb7u\x98\x00\\\x95\x80\x033\x9e( D&70{F\x99\xe9\x91\xabR\xaa`\xc0(\x1f\x05\xf4\xe3\xe3\xcd\xb5\x83'
        b'\xb9\x85\xc5\x19\xff\x8bm\xd1\x06\xd4\xebC\x1c\xe6w\x1e\x17\xdaw\xaa\xb2\xa9\xc7\x9f\xd9E*\x01f\x03j0\xf4f\xc5B\xd3T\x9d}\x04\x85<\xff\x8f\xe9\x04$\x8bW\xceX\x8e\xf7\xa1u\xa6X\xdb\\\x15\x116\xf5'
        b"\x14\xe7-\x8a\xad\x05\xb9`/\x80\xedU(j\x85s\xf1\x92\xc2\x9ao\xa5Pd\xc9\x16<\xce\xf3\x1cE\x11 \xab\xe0\xfd\xc9\xf7\xad_\x11\xff\xa5\x89\xd2\x83^\x906\x824\x1e_\xf30\xb9+g'\xaf\xae\xe6\x076"
        b'\x00\x80\xd3\xc1&yt\xf7\xa5\x11qZ\x0c\xe4Aq\x18\xef\xcf=\xef\x0b\xebZ\x1c\xa0|lj\xa9\x99\x9eE\x91\xe4\r\xc3\x90\x02/\xf0y\x18\x9bz\xbe\xd4\x89-jU\x1f\x81G\xf7\x16O\xe46\x0e:\xe8\xf85'
        b'\x97\xa9\x0e\x05\x17\xd8\xba\xe7\xe0<`R\xcf\xbdp\xb7\xb8w\xc9\x8e\x97\xa1f\xaa\x1d\xcdk\xcb\xaa,@\xffq\xf2\x87Sm\x85b\xea:\xb8\xfa\xe5r\x08\xd0\xb2m\xdf\t\xd91\x80\xb7\x1d}\x02\xc8\xfd\x1ag\xd3\x8a'
        b'\xe2\x83\xc0\x1e\xac\x11,e\x00\x10\xd8\xda \xf7\xd6\x96\xe9\xf0\xa3B\x97\xf4]8YG\xba\xe5\xe1\x00jV}\xe0\x8c\xa4\xb4Ko\x82\xb2\xc5)\xc2\x10^U\x05;\xd5N\xdf\xe0nv6!\x83\x9cCI$\xc3\xfc'
        b'G\xcd\xbd\x16Z\xb9\x0fz\x07n\xb9\x93\xecq\x8e\x0b\xd8Y\x8f\x03\xb5=@;\xc4el\tm\xf6\xdd\xc5\xf0\xf1\x88\xe5\xbb1\xa7\x8fO\x90\xcc\x1f\xb2\x12l37\xeb\x1b9\xee\xe2\xd6\x92\x91\x9b9\x99H\x87\xe0\x07'
        b'x\xca\x08\xd3\x17\xc0[.t.\xffX\x15\xe5\x1b:=\x1c\xa3\xac\x93sf\xaabY\x8c\xaa>\x9a\xf9\x11\x9b\x1d\xe4\x8c\x1e\xe2\xd4\x0c\xa4b6\x07I\xe8\xc9\xa2\xe9\x85s{\xee\xe1Y\xb0\x00\x11\xa0\xd4\xde\x1e\xff\x91'
        b'u\x81}m\x1f\xd464RI\xf9\xa4\xda\t\xd3I\xaf\x0c\x00\xec\xf8\x9fRW\xd0\xfb\xde~\xb1\xa0\xe5\xf5\xab\xc9I4c\x9f\xb4:\xf9OT\x9b\xef\x08\xf0\xb8\xf1\xec\xbc\x1f\x15\xffk\xb1\xb9\xa1/\x88\x8f\xdccX'
        b"\xbd\x08>\x8c^\xf7\xc6jg\xe02\xbe->\x86_\\\xcb\x01'\xd9\x98J&\xf56C\xd7p\x96\xf5V\x1c\xdf\xec\xa7i)\x99\x02\xf6\xcc\xe9|\xd0\x10\\\x1e\xc6\xd3#\x1e\x07\x150?R\xe7\x17\n\xfb@\xa4+"
        b'\xc5\x1a5\xd0\xa0\x0c$\xd8WVP\xbe\xf27y\\\xa9U\xb1\x11\xf5\xcb\x96\xcc\x87\xf4w\x02\xd4\xcb<.\xb5\x0bU\x19Uxl(0c\xda\x8b\x14\xaf\xdd \xe8U{\xb8\x8c)q\x98\x12cV\x9d\x81j, '
        b'\xa7\xb2\xb8\xa8\xb0\xd0\x9btu\xc2\r\xc5\x07g\x97\xefq\xc028R\xf3T\xb2\xf0\xfbK?^\xa9m\x05\xffn\x0b\xe1\x9fn\xc7[>!q\x1c\xa9\x9b\xfe\x82\xb1\xe6\xc8\x0c\x86\xbd\xeb\xa4\xb4\\\x13\xa5\x84\xf0\xaf\xd6'
        b'\x93\xee\x9a\xa2\xff\xa0*g\x87\\w\xc8\xc3d\x18\xe1\xeb\xe4\xab3|\xc7\xa5B\xe5U/\x05\xa8\x1b6p8\xf8\x06>.\xda+J5\x81E\xecoH8}\x00\xfb\xc0\x9f\xcd9\xc1m\xc6\x11\xe5\xf2\x9d\xdf~\x93'
        b'\xb3\xa5\x9d\xe8\x7f\xb6\x90\x84\xe2\xedhV\x8b\xa50qF\x01/\xea\x95\x9b,\xe7H\xe0X\\\xaf\xe9qp\x81 \xb0\xd1\x9a\xe1G\x92|V\xd6\xa0\xcc\xf8\xbb\xf6\xf5\x8b\x14\xa3L4b\x85\xf9\xe2\xba}\xcf\xf1\xe94'
        b'\xf7\xd7\xe7\xcd\xfd|\x85\x966c\x8e\xf7@AH\xe5\xafl\xd8S\x18\xd13\x027\x93\x1eH2\x19%\x9aB\x03\xbb\xb80\xc4\xach9\x96g\xe2DJ`\xc8\x1eFi!\x02\xa7\xa5\xfe+\xcc\xb7\xf7#Iu\x8e'
        b'\xfd\xf1\xc9\xe0\xf4r\xc2!\xff|\x8c\xe7\xb9\xde\xd5\x94\xddd\x0e\xfd\x80\xber\xbf\xa1d\x0c\xe6\x8e\xe8p\xa6g\xdb\x9b{PyOC$\x81\x9d\xd4\xdc;\x95)7\x99\xddx\xbc\x96V\xa8\x8b\x97\xe5\x07\xf1\xd2r\n'
        b"\xe4 \x1d\xb9\x97\xdf\x04\xb3\xc6\x82\x0cQI\xc8d'sG{S\xf0c\xf3\xee*\xf7\xf5I\x9b\xac\x84R\xd6`Y\x02\xf0\xcfo\xb9\xad\xe2S\xfe\x85\x8e\x1bJ\xe1`6\x00Y\xff\xc6\xf6\xd8X-'\xfcf\xb5\x8a"
        b'\x9e\xb3{\xf9\xadb\x82r\xc2\xcc\x89\xa6\xed\xd6E\x1b\xc5\x87\xcac\xe7\xc6\xa7iS\xbdo\xf7\xdaqW\xa1}\x1d\x90\xe6d\x00T\xf2\xaf\xf9\x7f\xb6Z\xb8\xb3\xf7\xc7\x1d|\x83q\x83\xc0\x9b\x01\x80\xae\xbc\xa6\xbf-\xee'
        b"q\xf9t\xa4'|\xc7\x15\xeebW6R\x14\xab\xbc\xd2c|Z\r\x1d\xdb\xebd6T`P\xbeT\xf1\x86\xfc\x0c\xa1kn\xa0\xae\x18uR(\x9a\xfd\x85\xf6*%\xd4\xb4\n;\xef/$\x0b\x85e`\xbdn\xdd"
        b'zM\n({X\\\xad\x0c\x8c\x06\x94\x15\xfa\x97[\x9d1l\x8d`/\x0f3\xa6\xaed\xb8V\x0f\x93$\xc7\xad\x0c\xf0\x110J\x89\x0b\x856<\x84\x88V0@q\x18\xf0\x9c5\x10]V\xfc\x02\xea\xe2\xad\x15\xf5'
        b'IG\x0e\xa2\x98\xb8\x02\x04\x82)6\x81\xe8\xcb\x1aG\x1f!Dw\x91J\t\x8ah@\xa9\xc0\xd6\xeb%\xb4\x15r\xae\x89\xc5\r\x1b\x8c\x83z\x00\xd08\x95\x13j)\xf8^\x1e(\x1a\x8e\x0b\xbev\xdeA\x81\x93\xf1W'
        b'\xea\xa2\x0c\xc4P\xd2\xafD^\xa7u\x07"S]\xefPU\x891U\xed9S\x99\x1b\xc1\x0c4\xca\xe7H\x8b\xc7\x14\x0e\xab$j\xa8\xac\x9cv\xd5\x89O\x00!C\xd72\x96\x9bc\xbe4\xea\xc6\xe5\x95\xe0\x8d`\x03'
        b'\x1d\x9a\x8en\xef\xae\x98\xba\xad\xf6n\xe7B\xea \xc5\xfb\xa4y\xb2\xe7\x00;q\xb3\xce\xf7\xcbf\x0bL\xe9"\x97\xca\xc5zF\xcc\xe8\xb0\xb0K\x13\x95\xb9s\r(\x03\x8a&\x95pe=\x96\xd3\xd0dK\xc3\xe5\xbc'
        b'\xdejE\xf5\x0c`\x12\xd2\xa3\xa8\xc5.\x85U9\xf8t\xf7t\x00\x7f~\xc6\xc2\xa7\x8e\xc8\x7f\xa0\xf0\x7f\x90\xcd \xa4\x1f\x0f\xed\x9bc|\xbdG\x02\x9cr\xda\x0c-i\x9f\x88\x8c\xac\xad\xb2/d\x1d\x1c\xe2LE\xb7'
        b't\x13\xc5]\x94@\xfaA\xf9q\xfa\x85\x08\xae^\xdc?\xee5\x18\xdfAR\xb2\x8a\x19l\x1a\xc2Ot@\x0c\xbd\xd3^\xdd\xc7^\xc0\x15\xf7\x10e1\xc3Tk}y~\x8e\xe6\x02\xdb\xf6\x84\xb2\x03E\x06d\xa9\x12'
        b'\x89\xe2\x02n\xc2\t\xe1Z\xa7q\xa0\x1e\xb2\xab\x87a\x9f\x87\xcb\x9b\xa6M\\\xe9\xf16Dg`\xb9\x11\xd5\x02\xc4\x8df\x99J\xbe\xc7|\x96e\xcc\x16J\x8b\xc9\x0e\x1a.\x91\x078\xf9\xad"uz\xa0\xd6\xf4\xf1\xb3'
        b"\xa7{)\xab\nyy\xbb\xa0\x91\x00V\xd3heH\xc7,|\xa7'\xf9$\xa6C\xd9\xd6\xe5>\x82\xb48\x8f\xecaX\xb8\xda>\x9f\xdc*\xccyN\xd9\x08?\xa0:e?\xb4\x17\xfd\x81\x11\xaa\x99\x15\xf9\x01\xdf\x12"
        b'\xff\x08z\x16AT\xb3#K\x7f\x8e\x08\x05\xd3\x8a\xe5\x0b\xf5\xb8\xfa\x08\xb2C\x9f\xb5|.\x11DRw\x97\xfe^lU\xa7l\xe6\xf0\x87\xa4\xa18b^\xcc|G0\xe9\xe8\x12\x9bHn\xc6iw\x9c\xbd\xdeep'
        b'\xdb\x87\xcd\x92Q{\xbd\x07\xeb\xc8M<\xba\xfe\x87\xbc2\xea&\xcc\xc9D{\xb6[\x8c\x12\x03\x9eh\xceR\xe4\xc9>\x05L\x81A{\xf1\xce\x94)\xfd\x96W\xe1\x9du\xb4\xc1\x1foQ\xf3X]0z:\xd1\xcbE'
        b'r\x85\x94\xaf\x1f\xf0\x9a\xe8\x01\xdby\xe0\xc8\x0f\xf6g\xd1\x02U\xde\xa6\xe0\xaf\xb5\xee\x0cK\xae\xca\xe0\x96(\xb2\nd\x8d\xa4\xf1\xc3\x95\xfct\x19\xae\x87\x1fj\x978v\x08\x05;\xfc\x84<\xc6\xbb\xfb\x1dBZ1h'
        b'm~\xc646$\x9f\xf6\xa3\x1c\xc2i\xf4/\x82\x02\x94F1\x13\x95/\x17K2\xa7ES\x8a\xb7y\xe8\x1bV{P\xb5\xf0mp\xc5\xd3\\zK\x98\x9dd\xe7r\x9b\x07\x06IP\x83U\xa3\x00\xeb\n\x87\x1a\xf9'
        b']\xe2\xad\xeb%\xf6\x0f\x05\xb1\xd5\xd10\xf7\x1d\xb3r\xf6V^\x7f\xd6\x9c[\xd3\x08u^\rWl\xea\xc5\x01\xe2\xa1\xea\x8a?\xea\xf9=V\xb2\xbb5\xa6\xdesN\xe2#I\x7f\xb0o\xd3\xb3\x8e\x00\x84E2\xd2\x8d'
        b'r\x93\xcb\xee\xfcuYX\xb6M_\x11\xa4\xcd\x18\x94\x8c\x11\xdd^\xf7\xa6\x0e\x0e&\xc7\x81\x90x\xfb@\xc3\xdc\xf8\x1c\xc3\x89\xf91=\x1f?\xcb\x11\xabG\x19\xb0^Xt\xeeHZYL\n\x8d*!Y\xaaH\xb7'
        b'A\xba\xc2\n\\i\x93\xaa\x85\xfd\xe1\xaegm\xc7\xeb\x84\xe9\x0c\xb4\xbb?1M\x95\xd3\x98\xb7P%\xa2\xbd\x13DO?5\xf8\xe3qS\xd2ZQ\x11E!\x97H\xc1"\xfdZ\x17\x9c@\xa1\xeb\xb92\xd87\xed\x90'
        b'\xc8\xa4\x9e\xd1\x13~,E\xd4<z}A\xdc\xa6Xg\x8f\x0c\xd8z\x94\xc9(\x8e\xee\xdap\xfe\xdf\xee\xc4A\xc2\x17\x02\x87X.mYO\x95\xb0\xb86c\xeaC\xaeZJ\x17\xb1Ry\xa9\x8bW\\,<Y\xa8'
        b'2\x9e\x16\xe8=\x12\xae\xa8ZUj\xd6\xbf\x01\x9b]v_7\x8c\x98 *\xd6\xb0\xeaU_CL\x1f\xd9\x174I\xb5)\xb9\xca\xfa*_n\x95\xe3pw\xc5\xe4X\xf1\xf7\xad\xca@\x93H\x8a\x19-\xfa\xdb\xaa\x12'
        b'b\xe6\x0c"\xd4\x81Zz\x03NZ\x99^\x0f\x8cA\xfa\xa5\xcd\xe9\xa8\xc7\x9a<\xe9\x98u\x93d\xf4l\xa4\xe7\x7fL\xcc\x14\n\xc06\xa3\xb0~&P"\xde\xbb)\xab\x92)\xf0\xba\xb0@\xa7\x96\xbb\x9f\x91\x171\xfb'
        b'C\x7f\xac\xf1g"\xe5{\xfc)\xdd\xf2\x87\x0f\xaaN\xb0\xb5\xd5\xd6\x03\xa4\x1d\xfc(\xf9Af\\\x94\xe8\xf1\xd5T\xe6\xe3\xe6\xba\x8aa\x8e\x82H=i\xc0\x1e0\x9d \xfd(`\xe0vz\xed\x93\xec\xe1\x85\xa4\x86D'
        b'\xf5Z&\xa5\x0e\xcd\xa9N\x91\xfe\xc1\x1a\xe8\xba\x06\xde9z\x19\xdbOb\x9e\xac\xf0\x13\x8e\xcf\x98\xf6\x08\x9c~$\x1d\xbbs\x01\xe2\x1f\xf2\xb5\x8d\xac\x88\xdfb\x04_\x9cy\xbc\xc8J\x12\x07\x9c\xec\x85\xe2c\xb2\xb8k'
        b"\xa8\xa6m\xad}A\xe1u\x19\x14\x9d\xe6\x00'\x1b\xb0\xc4\xf6\xbb&d#\x8e\x02\xe9\xd5{\x13\x17\xb9\x91\x11<\xf1\xc9\xc1\xc5 \xff\xa9}~L\xf5%\xe6Ku\xd4\xcb[\xdf\xb8 \xe6\xb7\xbc\x9f\rC\xb9\x19\x18:"
        b"\xf8\xd4\x15\xe9\xc4\xdc\x17\xee\xfb\xc9\xc7\x1b0\xb4\x87\x9a\n\t\xea\xc0\xc9\xbcE\xef\xa5\x12\xc6H%\xc7\x8f\x99p\x0e\xb9\x96\xf5\xf4h'\x05\xeb\xdb\xb2-s\x07M\xaf\xc0X\x99\xd9\xcd\x1a\x8f\x17\xfa\xaauK\x08JE"
        b'\xd4\x17\x1f"q\xea\xa4\xbf\x85\xf3\xe0\x90\x80>bb\xedS\x7f\x18\x11\x96\xdd\xa2\x85\x8e\x05\xf4~\xbf\'\'\x7f>DP\xc3\xe7.\xeawI\x90\xf5\x8f\xcf-\xca\xc4\x8f\xf5(\xf5\x8eElG\x08\xa2\x14\xe1\xc2>\xa3'
        b"A\x05\xe9\t\xb1!\xc9\xd8R\x193\xbe4\xeal\x85M\xad\xf3\xf1\x10\xd0\x7f\xac\xe5\xa8\xf3{b\xa3\xbb'/\x9e$\x89N\x00\xb2\xe0\xe00\xa5\xe5\xf3\xba`w\x1c\xf0\xcdj\xc8j\xa8\x1e\xbf\xdaOp;\x9b\xc5p"
        b'\xa1\xec\xdf\x03;8D\xd6\xa7W\x1a\x08M9^]\x85\xc0\x8dW\xaf<\x860\xc9\x15{\xc99\x0e2\x18\xe6\x9b}\x14O\xa7\xa4S%E\x96\xff\x10\x10\x84\x88\x0f\xea\xf3\xf0\xc8\x85\xe7\xc5\xb5\xfa\xa5\xc7\x08cck'
        b"\x84\xbe\x96<\xbc8\x97h\x03~xL~@\xca\x97\xb5\nf_\x03\xd2\xc6]'\x9d\x9b\x17v\xd7\x9c\x8a\x9al\xe17\xf9!\x90\xd0\xa6\xdd\xd6\xf4\x89\xa8\x842\xcf\xad9\xf2n\xe1gRS=\x92\x1d_B\xfa\x8e"
        b'\xb7i\xd71\xd9;\r\x1f-\xe7i\xa4h\x15\xebP\xb3ot\x81\xbd[gj=\xf74x\x88\xe5\xba(\xa2\xd7l\xac\x0bS\x86w\n\xb0\x8a\x9e\x91V\xfdO\xedJ\xd0z(\x8ev7J\x99q\r\xc0][\x9f'
        b'Il\xb0;*u\xc8I!\x04\xbf\x8a\x12\n\xab5\x80\xfe7PP0\xaeSi\x06\x9dA[\x82\x10OO\xc0\x1c\xd1\xb1\x1b;:N\xce\x9al\xbf\xed\xd9\xdfg-\xa2\x0c\x07r-\xa7-\x05E\x1ac\xbb`g'
        b'P>\x86\xbe~>\xa4s\x9f\xfe\xab\xad\xd6m!\xfa\nd\xccy~\xe5\xb7X\xb5W \xebD\x1f\x89\xda\r\xe4\xe7MHq\xfd\xf4t\x98\xe4\xd0\xf3O*\x81\x915z6\x1d\xf2\xd8q\x11\t\x87+g4\xf7X'
        b"\xf4\xab\x93S\xc5\x9eu%\xa0\xa0y\xe6t\xc8Z\x0b\rF3\x80\x05\x14\xfbi'h\x81$\xa2\xb9lE\x85+\xce\xf8\x08P\xd0\x9a\x1bQ_a\xe5\xd9\xf8\x8d\x81\x1c\xf7\x8aEh\xc4\x89E\x9c\xb4>\x98[1\xb9"
        b"5\x13\xf4_\x85%\x9c\xa9t\xbd\x02\xe88\xa7\x81\x92n\xb5\xe67\x88L\x8eu\x96'\xf0T\x97\xd9\xa5`\xb9W\xf2\xde\x0c\xed\\\xaa\x8d\xa1 \x18\x08\xb8\xec\xbd\xed\x96\xc0\x7f\xe3R:v\xcd\x1c\x88\xfb\x95\xa5\x0e\xf8"
        b'\xc3\x85\xe0/\xb6Y\x03r\xce\xe6$\xe1K\xcc<Z\xf4\x15\x11\xce\xf7\xb7\xbe\xd1s\xb0\xca\x95\xe4#ipm\xcb\xf9S9\xa3+eCXafb\x05m\x9dh\x14\x8aF\x11\n\xbd\x87%\x9b\x87\x91\xc4\xfdQ-'
        b'-4SI\xa1\xebF\xd6w~\xbb\xdcl)\xa3\x9aU\xac\xac6\xc6lb\x19{\xc9\xea\xa6ff\x94\x97\x9a\xc4\x98\x08\xea\xc6\xe8\xaf\xa3CO\xdc lW\xd5!\x99\xf1ny\x1ea\xf1|/]\x83p\x16\x92#'
        b'\xfaa{\xd0\x81\x92.\x1e,\x12\x12\x97\xbe\xba \xe2\x8fS@\\\xfdl\xfcJ\xe2\xf6\xd6o\xca\xf9n\xd3\xbe\xfa\xaa\x8b\xc3v\xce\xab\xc7\x82cQ\xe2U\xd7\xc9\xd7\x84\xe0Xn\xb9H\x97\\E\xe8\xbb\x15\x85>\xeb'
        b'L\xfco\xb0_\xf4>C+\x1fK\x07|\xe1\x85\x83@\xcf\x9d\xa5\xe4\x82\xf8$\t58\x80\xa9\xbd\xda\xc3\xbfk\xd1j\x88\x08\x8e\xc1M\xa8\xe53\xc2\xd6e\x00\tbb\x84\xffvb):\xe39.\x13\x19\xfe<'
        b'G+c[\xb3V\xc5H\x9c\x90\xc7d\xb4\xa8\x95\x07.n\xf1\xbe\xe5d\xd4\xf4\x9c\x12\xdc\x85\xd9i\x1bc\xb8/MC\xb2b\xaa\xb7 \x11&\xad\xc9\xbb\xe7n\xaa\x80\xd6\x9f\xa6>\xbf\x8d\xc9kb\xeb\x80\xd3\x96\xad'
        b'@=+\xb2D\xb9mEd5H\x1b(\xf6\xf2P\xb3;\xc8?\xc8\xe4,\xb1\n\xe6\xa7\xa2\xbdbc\xf8U\xf0M\xb1O\xfc\xb4W\x8c\xce\xb4\xa82\x91\xaf\x16\x8f2\x87!\x1eE\xf0\x0cdE\xd8\xb7\xeb\xc7\xa4\x9f'
        b'\xb4\x89\xa7\x9f\x16?\xc29\x00\x0b\x01\xa1.\xc1\x1bA\x80\xfe\xf9\xd6\xdd\x08v\xa3\x91\xe0\xd7\xce>#J\xe4a\xfb\xc1O\xf1&\xdd\xc6<\xb2\xff\x85\xc7\xd2\xd6/y|F\x89\xcap\xc1{\x91b\xab2o\xd9\x11\n'
        b"\xb7\\L\x83n\xe0\x01Y9-\x14s\x0f\xa5{\xd8\x8fMThV{\xf9\xe4'r\xc4\x98\xd6\xef\xbe\x9e\x1fn\xd3\x8cAf\x0e\xceu\x8cK\xd1`U\x1fq&\xfd\x17\xce\xfe\xa6-\xed\xdf\x03z!\xd2yj\x03"
        b'f\xc4\x12\xe2)\xcb.\xd4\xb3\x18\x16\xe9r\xa3\xbaV\x13\xc0tG\x7f\xfeO\x07\xd7QS\xdf\x0b\xc3+P\xb90\xf8\xf9\xc6\xf6\xcfG\x1eg\xe8\x9a\x14o(\xdd\xf5\xc5\x90\x04M\xe8\xc2\x15\xfd\x1b\x00\x8c\xd6\x87\xf5|'
        b'\x16\xad\xbe\x95\xb0\xebp\xcc\xf9\x96\x01b\xdc\xec\x8c\xbc$\xee\xa8@4\x85\xe8\xa7\x00dD9o,\xd8\xd0s\xac"\xb94&\x9c\x04f\xb1^\x98\xbf\x88{\x92\xb5`\x08\xf8\x89$N8\x8d\xfd\x85\xf3\x18\xd6\x8b\xbb'
        b'\xa8\x8b\\\x15m\x06\xb6\x84\xbf\xd2\xdd\xf0$L\xdd\xbb\x1fF\x98=\xf2\n\xe5\xf0\xaa=\xadz\xdai^B\xd4R\x82\xfb\xac\xa0\x8a\xf2\xf4\x02\xcd\xa2#\xba\xa8\xdf~\x04\xcf\x14\xe1\x9f\xf7\x93q d@u\xc4\xd7\xf9'
        b'\xf0~\xf3\x88\x94\xb0\xa4R\r\x13\x10lO\xb3\xc52\x7f\xd5v\xe3\xfb\x919\xd0\x0f\xbesZ\xf1"\xb0\xbd\xfc\xd3)J\x93\xa9w\xdc\xea\xc5a{\xd5\xfb\x07\\\\\x82\x80\xcf\x17\r\x1e\xab?0\x8b\xcfD\xd8\xbc~'
        b'\xe2\xe9\xbb\xd5&\xa39\xe1\t\xe46edB\xd9\xbf*\xc4\xfc\xad{\xc6)r\xeb\xf8\x94t\xf1\xa6\xb6x\xdc\xa8\xb1\x19{\xe3\xceg\x9c\xec\x86{\x12y\x07\xd5\x8e\xaf\xe2\xa213\x0b\xd4\x91\xf9\xe6\x9f\x0f\x0fEO'
        b'\x18Z\x85b\xc2\x0b\x82\xe2\xbc\xba\xe1\x80\x1fX\x98\xd6X_\xbcD5\xdbQ\xd5Q\xd2\xa4\xde/\xf8\\u\xf4\x81\xe4\xfc\x98\xfbk\x00\xa4S\xee\xaep\xfd\x95z#\xbd\xeb\xdc\x80H\xc1\xb6\xd6\xf9\xb8\xc8^\xab)p'
        b'"\x06\x1d\x16\xb8\xdeD5m\x1f\xcd\xd5\xee\x99n\x91Q\xac\xf0(^D\x19\xc9\xdbD\xd4\x81\xdcR\xb5\xfaf\x0f\xabJ\xc21G`\xa35\xb7T\x8f\x17\x059\x1c\xb5\x19m\xe9O\t;\x9a\x03o\x9fI\xf9G$'
        b"\xfd\xb9w\x1f-w\xcb\xb9\r$9\x19\x03\xff\x8c\xb2;Pi#\x86\r@+\xaa\x9f\xe6\x18\xeag\x00L\xa3H]\xed2\xfd\xc44\xbb\xba|S;\xa8\n\xe2=\xd4t\xd3\xa8%\xff'\xbd\x13\xe4\x9f\xb8\x03\xff\xf7"
        b"\xdb\x0b\xb3\xce\xd7\xaa\x00\x8d\x07\xea\xd7\x9e3\xf8\rF\xa20\x88\xe1\xdb\xa1\xc4\xff\x02\x95d_L4\xee\xde\x1dr\xeasb\xfb\xf9i'\xc3\xa5\x1b\xd5r\x0c\xb3\xc8xR\xb8\xc6w\x98\xe7kCeq}\xce~\x88"
        b'N\xfe\xc1\x90\\\x9e&\xf0\x99\xd7i\x98~\xbd\x8eO\xd2\xde\xce\xc1,\xa2\xe5{\x1e\xebe\xe4\xee\xb7\x81n\xe5"\xf8\xe2\x7f.\\\x1a\x8b\xb4\x99\x97I\xb0\x9b\x0e\x9e\xf1\xd2p\xba}BU\x13\xac\xdb\xc6\x032\xeaR'
        b'\xc20\xf4\xf4\xda\xb0\xda\x17eC,PC\xf7\x0bT\xdf\xe7\xb3rt{\xbd\x0e\x97\r\x94D\r#\x08\xb8\x9a\x9f\x15\xb3?\xe9\x15r\x12\xd6\xa7LY\x98\x7f\x04\x14>A\r\xca\t\r\xe3\x1f\x93\xb6\x97\xd5\xc7<\xb8'
        b'\x04\xa9n!\x1d\xb3\x16O\xcc\xa7\x11h0I\xee\xe4e\xe4\x08\x0eEU\xcd\xe6\x02\x19:\x9e\xa5\x92\xd7\xbd\xf1\xc1"\x94\x9d\xf4\xca\xaa\nz<\xef\x1b\xa1W\x87 uSJ\x834\x81\xca\x10\x02\xbb\x91\x15\xbbJ\xea'
        b')w\xa4\x04\x97$\xcc]\xe5W\x00\x0ch\x03\xb49\x8f\xc5\x06\xaa\xc0\x99\xa7\xf5\xa5f\xbe\xac\x16L\xd6\xdf\x00\xd3Z\xc8\xac\x8a\x82\xbe\n:T\xed\xa2\n\x88lS\x85u.\x94%\xd5\x00B\x81S\xf4\xb7\xd9j\t'
        b'O\x17\xfcYD\x88\x1f\xe1P\xcdmd\r\xa6\xb1\xd1\xe2S?1lT\xff\x87ST\xf0\xb6\xa5\n\xd0\xdaM\\\xfaX^z\xa7T\xeem\x077\x14W2\xdc\x9f%\xdc\x9f\xd9\xf0\xd5\x98\xc0\xad0\x1c-\xba\x01\xb1'
        b'\r\xfb\xaa\x90\x9d\x90\xc4\x94\x87\\</,\xe3;\xf2O\x84I\x15\x82\xcf\x9d\xcfd\x15\xff\xca\xf6u\xd8B\xac\xae/C/\tWH\xb1\xecN\xeb\x14_\x18\xe8\xd2%)\xbaZ\x7f\xc4P\xc9p\x18\xd9\xd2Z\xf0\xb3'
        b'\x1e\xb6$\x01\tF7\xe6\x98\x873T\x86\x9eEH\xf2\t-\n\xbd\xca}@\xf7K\xd6l\xd2\x1b\x98-\x9d\x0e\xccG\xd9\xf6 \xad\xcc\xcaKH\xb9\x0e\x9f\xef\xec\xc4\x05\xaf\x1e\xf4C\xd4\x19Ii\x94wB\xc3\xf7'
        b'\xae\x83\x7f\xed)\xf9\x0e\xefh\xae/V\xfb\x8c\xc1\x0f\xdcT-q\x9b\x08\xe9f\xac\x13e\xccw\x05 \xfa\x81\xbe\xfa*\x82e\xe0#X\x80\xc7B\x1b|\xa3\xb5\xb6\xd3+4\x1fU\xbd\x03\xe2\x85\x08)@\x97\x1a\t'
        b'gz\xc9mDd\x1d\xb1\x1e\xa2\xa7\x8bW:/r\x7f\x84\\]\xbf\xe1\xd2Il\xd3\xaf\xdc :\x90\x9f\x14#B\x8e\xa9@\x88\xfe\x12\xa7\x95^\xfe4\xc2\xa1\xcfI6\x8aOl\n\x9blg`\xb8M\xd6\xa0\xa0'
        b'lo\xb1w\x9a\xb5\x89\x121L\xee\xa5\x08\xdd\x12\x9d\xdf\xdc]R\xa9\x0c\xdeUX;\xda\xac\xaa\x8f8nu\xfe\x08\xb0o\x04\x07R$:8\xc09\x98o-R]\x14<\xbeB\xf7\xd9\xec\xf4\x0cO\x18`AG'
        b'Vu\x8c\xeb\x7fb\x9f\xab&\'\xd8\x8f\x8c&\x80%\x83\xb0\x82\xf2\xd5V\xee\xeb\xd3\x9fop\xaf(\n\xb6\xd1\x96S \xb5\xc8 \x93\xff^\xd0K\x1e\x86%I;\xbe.J\x16\xbeKk\x85\xb0$/"|\x00\xac'
        b'\xdd\xb5\x0e\x9a-w\xf6\x96\xc5\x9a|D\xa2\x14Z\x0e\x1f<2>s`\xb9\xac\xdfm\x88L\x84\x90\xe3\x93\x10\xd0\x8e\xb9t\x93\xda\xcf\x1emITz\x89\xdf\xc8\xd5\x84\x08H\xbdg.\xee\x953\x01,Ml2\x9b'
        b'\xaeP\xf7\x1e\xa8lJk\xba\xf7\x1d\xf4F\xbb\xb0|\xa7\xbd\x0c\xe6\xb0\xb2\xd3i}\x06o\xb7\x92yg\x8e\xbb\x8d\xaf\x19\xdf\xd8g0q\x06\x07t\xae\xba\x13\xd9\xb28U\xcb\x07\x92i\xf1\x85\xcck)\xd8\x1f\xfcR'
        b'\xf3\xfe\xc7Io\t\x06\xe3\x1cp\xee!Cz`\xf7\xac\n8\xd1\xb9\x85\x16>\x8a+\xb8\xe3\x8e\x81\x8b\xcb\xf3UF8s{\xf9|DG\xf4\xdffC\x05[\xbf\x14\x8c\xdf\xbbO\xcf\x12u_\xa3?-\x04\xf6\xb6'
        b'\xf4e\xb8\xfaa\x9b\r/\xc5\x16P\x92\xb2\x9c\x81\xf67\x9awU\x90\xda\xa3w\xee\x8cY\x93\xb5_\xd17\xee\xe9\xb9\x96\xa4\xedN\x89x\x942\xc6\x1b\xc9a\x12V\xf1\xc0\xb6D\x97\xa0+\x86\x91P0mw\x7f\x84'
        b'\xf7?W\xb1\x19\xc7\x1f\xc5O\xb6\xdd\xbd\x1ei8\xad\xf3\x10>J\x8d4\x9c\xfePE\xa2\xc5\xcf\x97\x1c\xae\x80L/\x1d\x9d$ir"L\x9f\xdd\x93\xa5y>\xe7E)\x91o{\xc2\x7fM\xb5\xa1\x16\xb0kl\x84'
        b'\xfa\x07\xdc\r\x96\x13\xa7\xe8\xb7/X%\xd0\x13*\xf5\xc6\x9d\xc8s\xcb\xd5\x03%8\x90\t\xe2@\xc7\xf5P\x87\x9d!\xa2Z\xc9\x82\xe9\x0cK\x7f{\xf3Z\xaa\xd9*\x9d\xa6b*Z]\xb5Y[en\xd3\x86"\xf9'
        b'l\xf0\xf6]\xa6\xc9\x11|\x064/V\xef`2\xc3\xa0-\xb1\xbe4\x8d\x82\xc5\x1b\xcb\xbc\xeck\xeaA\xc7\xa7\xf8\r4\x9b\xf2"\x9b\x0fZ\x15\xe2\t\x85\x97\x00\xbb\xc3\xb9%N3\xe2L\xb7\xef\x1d\x7f\xda\xe1\xfe\x97'
        b'\xa9\xf5\xad\xa91\x0e\xd9\xf6\x92R\x80\xe1\xdcHC\x8a\xcc\xaa\x05\xc7\x86\xbe\xd6\xa1\xddh\xef3(X\xa5\x96f\xf9\xcap\x87t\xca\xc8\x16\x0c*Y\xe8`\xd2\xaa\xf0\xf0\x0fR\x8e_\x07\\\x12\xaf\x19\xf3@\x81\tJ'
        b'.\xb83\x14\xf1K\x93N\x10\x1c~\x8ehD\x10\xf5-\x93ot\xbfJ|\\t\x068\x1bNw\x08\xb6\xf35Q\xf5\xac\x97:4\xd9\xd6\xe49h/m\xae\xa7\xdd\x0e\xb4e\x7f\xdf\x1e\x10\xd5\x18\x9b\xed\x99\xc4\xc0'
        b'\xff\xaax/\x842\x80t\xbeGp\x97`>_\x8dh\x18\x01\x7f\x83d\x06\x85\xfa\x98Q\xcc\xe1\xd3\x14\xd0c\xd2\xc7\xd6\xfb\x96\x17\x9b\xe7Q\xd3H\xd8\xb6\x0c\xcd\x99\x10h\x9e{R\x08r\xa7\xf2\xd3QW\xabA\x95'
        b'\xd4\x9f\xbc>n\xa4\xe1\x8d{\xf4F\xb3\x1b\x88JJ\x80g\xe4W>\x9ag6\xc9_\xbak\xbe\x1a:\t\xce\x1a\xe8\x93+\r\xd6\xf2\xddu-d5\x9e\x96\xc0\xf91\xdbd\xf9HS\x07U\x8f\x8c\x16\x9bxG4'
        b'\xc2\xe7\x06\xd9\x8f\xa8\x8dO^=n\xa5G\xe6\xcf!\xd8\xd5M\x0f\xa9\x01s;\xado\xf2c\x98\x1d\xcd\x99\xa3\x9c\xd2\xcb\xd2\x96\x16M\x8b\x1f\xe5*yHL\xf7\x9b2"$Jv\x97a\xa8\xcf\x0f\xd2\xf5z\x87~'
        b"\x9a\xeb\xae\xd9\xe3\xe1\xa5\xae'\x87\xe2\x15\xcdY\xdeIGK\x88*\x07\xd7\xac\xa5\x8dmW\x15}\x00\x87\x02\x10\xaa\xfdm7,6\xad\x8bI\xda\t\x99(\xd6\xcc\x9eH\x0f;\xda\x9e4^ \xa1\xd5\x15\xfe=u\x85"
        b'j\xe2\xe57\xf0\xef\xb3]\xd5\x9fO\xdb7\x88\x87\xc5\x01*>\x01\xdc\x1b\x06\x08\x01\xb3*\xbc\xc1\xe4\xc8QB\x96\xb9\xb5r\xdc\xc0\xc3\xe8}\xe2\xe6~x\xf7\xde\xdc\x93\xa2Cc\x18x\x94\x9aBL\xaam!I\xc4'
        b'\x15 \xa7\x0b[\xc6\x827mw[\xd8\xf4\xf1\x1es\x17\xef\x01\x81}\x11?\x1d\x98r9\xbc\xd5\t\xe9\x9dx\x91\xab5\x90]\xebnH\x87F\x9e,V\xaa\xaa\x891\xc8\x16\x18q\x80\rN\xdb\xc0W#\x1fi\\'
        b'\xa0\xf0f\x07\xd3\x8b\x1e\xbeK\x00D]\xb6\xd9o\xa7qo\xe1$\xeeh\xef1^\x04"\xa9\xc8\xa1\xdb\xc0T\x9f\xd0\xea\x9f !\xdc\x12\xec\xbcL\xe7\xaa\xaf\x8d~]\xe8\xa0i\xf9P:\x8dV\xac\x9e}\xc2\xe3]'
        b"Y&\x9f\x96J\x8f3\x80\x8d\xb0H5fOO\xf5Y%\x89\xf1u'\xe4O\xe1\xbcRb\x18\x89\x8c\xd5\xe6\x83\xd27l\x04\xa6^9G\x1aH=\x1c(\x1d\xe3\x9e\xc9~Lx$$\xadL\x14\x14H\xcc\xc1\x12"
        b'\x82\x8f}\x99Z\xff$\xa7\xacz\xa7\xa7\xa2\x95z;\xdbi\xcb*\xd5>C\xf0>\x07\x92\xdb\xdaW(\x83\x0f\xe11\xe6\x98\xd3=\xc3A@%S\x9b\xd7\xce\x8e\x99\x85\xe0\xb152\xd2\xc3\xddW\n\x02\xc3\xcbC\x06'
        b'r\xbcb>\x11\x03o\xe5\xc3o8\xe9\x98\xaf\x00\x00|\x82\xa8#\xee\xad\xaa#\xa23\xf7\xc9\xb3{\xda\xc3Em\xba\xf0\xa2n)-\xf0\x93\xee\x1f\x17\x18\xee\xc6\xc7\x10\xa2\x9eq\xefo\xad\x95\x9e*#O\x17Z\x06'
        b'\xc6\xcd#\xf5S_\xc8F\xd7\xc6\x04\\\x84x9\x16x\xf2\xecY\xf4\x9b\xad\xd4\x01h-\xa3\xf3\xaa\xb4\x95\xac\xdde\x87\x0b\xbf\x07\xb1_\x91\xf5\x15-\xda\x96.\xeec\xc5\x7fA\xf9\xa6)\x95\xf4,3a\x8d\xc1>'
        b'B\x8d\x90\xc7\xa0c\xb9\xdb\xcf\x96`\xf0u\x05\x80\xdb\x19\x13>\xcb?\xae/\x00\xf3^d\x1c5k\xa6r\x153\xe8{mll\x12\x8a\xb4\xf7\x90|\xc1\xc3\x1d\xd8\xcd|w\xc7\xf8\x88\x96\xe6\xd7\x8f:\xa3\x12n\xb4'
        b'\x0c5\x80\xeb\xa8\xe2\x0c\x9b\xbcw\xf5Ou\x82\xd6\tc\xc8G\xf4\t2\x19\xe0\xe4\xc3\xc2\xd92uZ\x9c\xbfTd\x95\x8e\xfd\x8f\xca\t\xf3\xae\r>iZ\xcb>\xc0\x8bj\xa6\xe9\x0e?\xcb\xf5\x17\x98SA\x00e'
        b'\xa9\xdfs\xf20\xc3\xedG\xd2\x12\xd1A\xb0ytk^\xd2\xcf+<\'^\x93\xc9rX\x19Y\xf5\xc83\x8d"\xe3\xb1\xef\xd01\x02^P&\x07\xe6\x12\x8b}\xa3\xab\xb8(\xa0p\xe3,\xfdDk\xfa\x18\xe5E\xba'
        b'q\x99\xeaz\xc9\x07\x87"w\x95\xdaO\x1eA\xc6\xaa\xa6\xa5\xbd\xcf\xb2;\xda\x92*\xb1\xefob9D\xc7\xdcP\'\x1fg\xf5\xda\xe9=_9\xe4\xcd\x0bk\x98\xd9y\x0f\rR\xa7m\x8f\x96\x04\x1b\x0bSIC['
        b"\xfa\xd7\x03_\xe7\x04d\xdd_<\xde*\x93\xf0f\xad\x1c\xd8'\xf8@p\x9c\x06\xc1\x9d\xdb\x0b\x05\x88\xe9\x89\xed*K\xd9\xd9\x9e\xf0\x05\xdc\x89\xc7\x0e\xdf\xfc\x80\x18i@\xda:5;,\x8eE4-\xf2\xde\x1b\x1fN"
        b'3@^\xe6<\xcf\xfc?\xf0\x8aY\x1b$\x06]\xe8\xb6\x17\xd3\xe3\x9b\xf8\n\x96\xcd_FC\xb1\xca\x0e\x0c\xe3$\xd2T\x95\xbc\x17\x8d$E\xe8\xd4\r\x9b\x8c\xa0\xcb\xb0,\xa5p\x03$y\x12\x18w\x98\x12\xadB/'
        b'\xeb\xca\xcd\xa7\xb6h\xd2\xa0\x99!x/wv>\xed\xdc9_2\xf2+^\xc4/=^2\xbb\xd5\xd9\xfbm(\xf7\xbd-p\xe4\x8a\xda\xc1\x98\x89\x08\x86\xde$7bv\xd3\xec\xde\x8d!\xef/`-A\x1b\x8e\xd1'
        b'z\xed\xac\x0ed\x16T\xd5\x0f\xae\xa6fq XE\x004\xf9;A\x89\xa0A(\xcb~\x91\xff\x9fFVSS\xa5\xedz\xe7q\xf6\x08M_\x9e\xaaA\xdb\xa0w\xa2\x1a\xd9A\x02\x01\xc8C\x1b6l\x1c\x8d\xc61'
        b'\xd0\xd6\xdd\x18\x0fr\x13\x03\xbb<\x17\xef\xa9u\x83\x16\x11\x85t\x89\x05D\x8c\xc0\xe13]F<{`\xcf\x12\x8f#i\xe0\xb5\xf9\xf0\xf40=\xd6X\x1b#:/z\xf2:)Wc\x86j@\x02\xf9\xdbb\x84)'
        b"_\xab9\xcd\x19\x1eK>\x18\xa4M\x83\x1c\xcb\xb5\xc2\xd1#\x14e4N\xc0%\x07\xd6H34'M\x8f\xbb\t\xab\xec\xa9\xac\x82\x86\xa9\xcd\n\xf9\x05_\x08'100B%\xcf+\x1b\x80\xff\x1e^\xb2\xfe\xddu"
        b'\xc2\xb8,Leps\xcfS\x96i\x80O\xcfu\xf5\x88\xed\r2\xec\x10a\xe5\xd2\x9f\xd8pm\xa3\xbb\xe4\xd8G\xe0\xd8\x16^N\xd2\x84\xd2\x8b\xd4\xcb_\xacOx\xe04\x08\x18\xff\x7f\xb9\x94g_\xf8\xe2\n\x13\xde'
        b'\x00`\x9a&\x81\x17\xbf\x12\xb9\x02\xf8o\x03\xed\x8aY\xe7_\x98_\x0bn6*m\xfd\x06S&\x8ff\x90\xd4=\xaf\xfe\x94\x91 \xa7=\xdd\xb5\x1cK\xa7]3>I\xca\x02Ze9\xa6\x89|\x1d\t\x9a\x05\xcf\x9d'
        b"\x92\xb7\x8d\xd6`\xfc\xb2\xc5s'eHu\xf1\x12_\xac\xd3\xd5\xf9\xa2\xd1\r\xe0@R\xa5p\x14\xf5\t\xba\x8b\t\xe6\xd9\xd5\xe7\x89$\x1c\x97O\x80\xa3\x8e3\xcd\xd5\x83\xff\x95\xc0\xa5\x1e|e>Vzp\x02\x8e\x88"
        b'\xe4\xd5\x15\xc4\x0c\x19\xdd\x84W\xe6\xdehn\xde\xf5?\xea\xd8\xfe\xab\x8cK\x9e\x92O\xd6 \x7f#^\xbe/\xb9\x8b"\x86Y%\xd5k\xcc\xffd_G\x80\xe2\x18_\x03\xdfx\xf4\xe8\xd7\x1f\x8d\xd9v< \xa1\x15\x99'
        b'N\xc5J`\x8d\xe0#i<\x0c\xbe\xfa\x9e\x03\x97\xfe\x0c\xb1\x87qq\xa2&\xaa\xdc\xe1\x02\x11\xf0\x02E\x14\x05t4gpB\x99M\x06S)\xa0\xdf\x9e\xf0\xc2q\x1c\t\xc8\xb8z2\x19.I\xdel\x141\xfb\x91'
        b'\x91\xb4*\xda\x1e\x96\xc0\xa6v\x06\xca\x7f\xa4T\\\x80\xfem\xe0\xae\xb6}\xbd\x89K\xf5\xce\xcf\x05\x93\x05\xbet\xbcV\xed\xd2m\xd8\xa0\xaagC\x11\xdd(s\x84\x18\x94K\xb2p\xceWX\xd6\x17\xd3\xd6Xk\x06\xc8'
        b'`l\x0f\t\x8eS\xbd\xa6\x82\xbf|\xb6$QI\xfa\x96u\xb0[\x85\xbc\xc0H\x99\xb1\xa1!@\x8aOx\xf2[\xf1P\xca6\xc8\xd5\x99\x87 G\x80q\xee:\xea\xd7{\x0c\xf31C\x19\x01\x9dX\xe3<\xdbWR'
        b"R|\xd0\xad\x13\xb2\xcb\x1c5\xfa\x04\xa1\x1aF)\xe8\x9aUyv\xba\xa6'\xcb\x15\xa6\x9b)\x7f $Ydp\xc2K\xa6\x86P\x9b8x\xbc?Y<\x1d\x06Ev_\x92\x0f_\xdae8\x14p\xb4f\x8d\xbfj"
        b"\xfe~t\xd2kj\xb6\xecO-\xa9\xf6xD\xc2<\xef\xab{\x17\xc5\xc0D\x10\xdc;\x870i\x9e\xc6j\xbd\xc8\xb3g\xfai\xb4\x136+\xd8\xee\xd5]\x0b\x97\x11\xfa\x17\x99'\x10\xf8z+\xfd\xf4\xe9\xe4\x87Q\xaa"
        b'\xa9\xb8F7\xafh\x87\xb3\x9f\x00\xd9B|\x0c\xca\x7fU.\xbe\xd4WI\xc3\xa1\xb5\\\xb6\xb1\xb6\xee\xb9c\xf7\x9c\x8dI\xc3\xe2\x0e\xa6\x96}@*\x89\xfa$\xd8&\xca*y0\x161\x07\x19\xf1We\xae\xef\x06T'
        b"wr\xa9r)\x85\x11\x1b\x19?\x1dQ\x92q\xd2\x19\xc2\xee\xdf\xb74\xef\x8f\x9e\x05\\\xc1+>3<.cZ%\x95\xa8\x92\x82\xf6`\x06o\xfb\xd8sG\xb9\x1cE\x18\xee\xa8\x13\x82aiG \x9b\xb4\x0e'\x80"
        b'\xfa\xeef_\xa7\x11\xf4H\xbd\xf2\xc6\x1a\xd9\x12\xa8Dg\xb8C\xf4\xd1\xa2\x08\xce\x1e\xa6|\xff\xb3\x9f\xa5M\xdbm\x0f>\x94%[\x86\xe2\xf7\xb3\x9c\xbd\xb9\x81\x86u\x0f\xb1\xbd]\x92/Q\xd4\xb0\xebO}\x06\xadw'
        b'\x06\xea\xfd\x94L%[\x04\xeeS\xa8,\xf4FO^\x93\\a\xb0{\xa7\xe1\x0eh2H\xf74\xc0\xad\xc4\xce\xfe\xa9\x19\xce\x08\xd0$E\xb6XPC\xf1u&\xaa\x9c\xa4\x97~\x97\xa8g\x8e\x14r\xa2=\xee\xaa\x8a'
        b"\xe5\xf8\xb0\x7f{\xde\xea\xf3\xe3\x00{ \xdd,\xa1\x05=a\xf3CD9\x9f\xa6\xcc[\x89\x03z\xecf\xcbA\xa2\xe1\xe1\xd6[g\x1ce%\x1b\xeb\x11$\xdc\x1d\xc5\xc9q\x0cn\x9d\xf4'\xb71\xc3\xc7\x0b\xbe\x1d\xc0"
        b'\x1b\x84\x01\x15\x9b3\x98\x0b\xd1\x15~\x99\xa3\x99q\x12A\x84\xdf3\\\x80yFu;\xd0v\xa8\xd7\xb4\x9d\x89"^n\x87\xb2f\x05\xe3\xc0\x1b_\xb40\xfc\x0b\x11@\xdcv\x14\x1c\x18<\xa8o\x86gT\x1e\xaa\xc6'
        b'\x94h\x84a\xc9\x0f{r\x14\x12u\xec\xc1C1k\x19\xadD\xb2\xce\xde\xe7Q\x00fm\xc5\xc1\x84#{\xa2E\xf8\xb2\x03\xd4Xm\xbe\xf6\x14\rb\x1dO5\xa4n\x04\xf5\xec\xc5*\x1d\xa2\xc5sM5\xd4\x17\x9b'
        b"i'\x8d#?d\xbb\xa6\x86\xcd\x15\x19\xb8\x1a\xf3\xb0\x8d\x8d\xd6x\xba\x84X\x00\x1a\xa3\xbe|C\x8d\xf4\x85\x15#)\xf2\xc5\xa6\xc4^\x83\x85\x92\xc5\x1aT\x0f\x80\x9f\x12\x1apI\x1e\xe3\xf2S\xf2:xb_)!"
        b'8I\xa9r\xf1 Lg\x925\x9c<TO\xb4\xbe\x18\xa2\x10q)\xbdJ|\x86\x15v\x17\x85\x85\xd0mr\xd5F\xd9\xf3p\xd6\x03\xbd\x85#V\xa1)\xe7\xc85\xae\xe6\xde\xdcd\xd4(\x9a\xc0}q\xa2 ,~'
        b'*\x12i\x97n\xc3\xa1\x08t\xb0\xe5\x95\x15\x8f\xf5|\xa4\x08\xe1\x9f\x80`|#?s<U\xc0$$\xd6K\xcet\x11\xf3\x0bg\xd7\x98p\x8aI\xcb\x9eHJ\x19\x89\xeb\xfd\xad\xdf\xd3\xc9\xde\xb2\x9f\x7f\xbd]\x8b\xd1'
        b'\x15\xbf\xa5\xc0n\xf1\xf4\xb6\xe3\x1e\x1bfgv\xdc\xa7\xa7\xda\x7f\xc0m\x96\xeb\xa3\x0e\xf2\x90\xc3\x0c\xaf\xca\xc4\xe9\xc1\xd4"\xc9\x84\x1f$\xf4ri\x11*3\x1aY\x05\xab\xe1\x05z\xbf\xad\xc0\x91m\xf7\x16\x9a\xe5\x14\xb8'
        b'g\xe5r\xa0kS\xe1\xc5f\xa2v\x937\x9f\x8a\x0fj\xf2\xdd\x88\xbf\x8d\x81w\x89\x82\xf7x*M\xad\x1b]4\xce\x988.\xa6\xf2\x05!\xc2H\x84\x98\xfcvX\x15\xf1\xdfif\xb4\x016\xe1\xc4}v[\x82F'
        b'~\x1a\xd8\xdaZ\x9a\x0c\xc6\x1cv\xe0\xfe\x01\xbauxpI\xfeH\xec\xb8\xacA\x12*\xd8}\x91G\xb0b\xa6\xbcs\xaa\x89\xe0\xdb$\xb5\x83\xa0o]s\x05\xdf\x1c\xe3\x8a\xb3\x8e\xf5h1L\x08\xf2\x1eq\x83\x92e'
        b'C\x91\xda<^:\xccz\x0bn\x0b\x17j45\x8d\x9aE\xad\xdd\x95\xab2JZ.\x07\xd4\x9d\xdd\xf6\xec\xbb\xc94\x80Z\xa1\x16\x11\xe1\x17\x81\xed\x80\xd3\xdb$\xc5\xc2\xde\xbc\\\x19\x91\x8c\x9c\xd1[\xe7\x0eV\x99\xae'
        b'XJ\xef\xf2\x98\xeb\xc1$\x98\xb1\xec\xb0\x03r&1\x9a?\xbe\xcd\xfe\xa1\xa9\xb8u\x97"\xbb!\xf1\xef\x8f^\xc1;\x83\xf9m\x80\xd4/9\xa8*{{\xaf\x99\xbcC\xcd@grt\x1c\xbd\x98Y3o\xc2\x0c\xa1'
        b'8\x8e\xb4Eg\x02t#\x94\xc8MU\x80\t\xe9S\xd2Q\x9e\xca0\xf9\xff\xe7\xe1(A\x1b\xa3\x82[4\x8f\xb8\xe1\x9a\xab\xbf\x82$\x94I\xd1c\xbf\xdea\x12{*D\xd9\xb5"\x07\x18\xae\x92x\x8di\x1dn\x17'
        b"2M\xcb>t|\xc5\xa6,\xcf\xe8}5(7,q\xa6\xf5-xz\x0fb\x0c\x12\xbe\xb9.'[\x97\x9f\x87\xb9\x7f\xfef-\x9e4v\x06\xd2ys\x97\xc0\xf7\xac\xf1,\xcd\x03\x1d\x08X\xdb\x8ff\xea\xf9\xf7>"
        b'wP|\xc8\xde\x85\x8bo4\xe6\x8e\xa6g%8A\x9c{Ex\xe9\xeczK\xe4\x03n\xd0\x9c\x88\xd5\xccU\xf6\x1a\xdb\xf2\x14T\xbf\x87&\x9aY\xdb\xb8\xcdM[P\x88\xf5S\xe6*!pZ\xd6\xcd0\x06\xcf\x9c'
        b'"\xa9\x1a\x85\xbf\xe4\x03\x82\x1c\xb5\xb1\x9f\xac\xc9Cq\x8a\xc8b\xa4\xf9\xc1\x19 9\x18]\xcfC\xa6\xfa\xa7w\xc2\x93\xf5\xdc\x97\x12\xb8\xae\xef\xe8\x01\x8f\x18\x14\xa9\xa01"\xf9@d{23\x8c\xd12\xb9\x03\xb9L'
        b'15!\xe2\x06\x12\x03U\xcd\x84~M\x96\xfa~\xbc\xce:\x1f\xba\x9d8\x01\xb6]_\xd2\x15\xdaH(\xf93\xc4\x12akzV]\xb6\xf2R\x13\x8d\xb8\xc6\xc5\xf6\xa6\x12\xc5\xd0\x18Mr\x8d\x15\x1d\xc4\xf6"\xd8\x98'
        b'\x1d#\x96]Z\x81Iq}=\x92\xc2\xd9i`u5%\x81\x82\xaf$\xb9\xe7\x8f\xfea\xde\x0f\xb4\xdekmd\x0e\xc0JDrUc\xc3\xa9\xb1\x1f\xbd,\n\xe2\xf9x\x9ac\xea\x82\xcd\xe9\xd0\xc4\xe01\tO]'
        b'\xcd\x90\xe2\xaeD|\x18\xdb\n\x88\x80\x92\x17*H\x83p\t\x95s\x91zKfX\xeb\xb6\xd6\x08,\x15F#\xa5\xc5\xf7(\x1cq\xe08\x1eh\x0ed\xc9p]oY\x141p\x8e\xf6\xf2\xec\x1f\x87\xaer\xf0\x01\xec'
        b'Z1\x1b\xf2\x0b\xb0\x17;\x9e\xaa.D\xa9\xffG\xa4\xd5\x11\xc5y\xb6\xbb\xe9\xc6Q\x93R\xea\xb2\x11\xaf\x11\xfb-<\xe6\xf2\xd1\xbd7L\xdc\xf6#\x94\xb7\xcc\xcc\xba\xfe\x1a\xfd\rNR\xdbO\xee\xfaoh\x07\xedi'
        b'\xc8\xc0\x14\xb9R\xcf\xf2\x96\xdb \xf6\xdf\xac\xe29\xa8:0\x8a\xc8II\xcd\xbe\x0c^\x8f\xaa\xe7\xea\x83\x116/wT\xf7\x85S\xf5\xc7\xe5\x9f\xb6\xdaxZ\x12\x0b\xb1\xa2\xa5\xe6K\x84\xe3\xa6>L\x8dOS<\x1d'
        b'\xa0pb\xbb\xbf\x18\xea\xea\x0b\xbd\xcc\xeat\xb7\xb5\xfa\xf3\xa74N\x02\xde\x94M\xdd\xd9\xc1\xbf\xbb\xe7\x9au\x1d2\xa2\x97e\xfa\x11Nb\xc9<\xfaz6\xac\xba\x8an\xf5\x0b\xcf\xe7\x1f&8\x93\xf6k\xd5W\x81\xaf'
        b'\x13ib\xf1\xce\xf1\xb6U\x86\xcbGH\xe0Byu\x15\x7f\x8e\x8e\x99fj\x94\x02}Q.gF{u\xb0&\xc5\xc2\xae\xd50a\xee\xb2/<ZJ\xd7<Nh\xf2\xa9\x112\x10\xab%\x8b\x00jt\xba\xb8\xe6'
        b'\x17\xe4\x0c\xf4\x05\xbcq\x8a6\xd1\x12\xc9W\xd6\x1e=D_\xea\x13*\xa3\xdfM`\xa0\x7f\x1c\n\x18s\xe7\xd5R\x87\xea\xffr8)\xebC\x19N`t\xf3\x04B/IhT\x12\x12fp\xed\xbd]#EH2'
        b"m\xfc\nn\x82\xae\xe47\xc6\xab\x1a\x96\xca\x1f\xe4/\x0fA$/\xcd\xfc\x05\xe0\x17'\xd4\x1e\x15\x1b\x87m\xcdI\xc69<\xe1\xb8\xa9\xf4f\x18@\x82F}\xf5\x81u\xf4\xd9FpF\x7f\xe2\xa1\xbeH\xdfL\xbd\xbe"
        b'\xdc\xec\xedJ\xa9>\xf8$\x87tm&\x02r\xda\x9a\x95\x0e\xeeSWD\xc4\xe3\r6\r\x9e\xd3\xb3\x918\xd6\x9fh\xfc\xd7\xe3\xe6Z\x19\x07\xbc\xcb@\xe6\x8b"K\xe7)\xf8\x06\xd16\x99\x1c[\xbe\xd3\x06\xfb\xd8g'
        b'}|\x83B~|2\x87\xda\xcfj\xcf\xbf9\xb1\xa8\xb0\xd6\x9d\xce\xea0\x178{\x8b\n\xaf\xd6 \xff\xe1\x13Ry\x96\xd6\xfd\x11\xc7\xc8\x9e\xabV\xa0\xe1\xea\xa8\xc4\x8b=\x8a\x10~\xc0\x03\\U\x025)\x1b\xe7\xb1'
        b"b\xe5\xc2\x12\xde!:g,U\xde\xcc\xd1\xa4';\xb8\xfd\x80X\xef\xd2/\xe4\x0el\x13\xcex\x03\xb7\r\xd6\xcc\xcaSM\xd72_*\x11\xec\xdf\x1f\x81Z\xf8\xd0^r\x83\xd6\xa1\xf0\x12\x07\xcd\x9cn\xa0\xde*\xb3"
        b'\x1e.\xba\x18\x1c\xf9\x17\xb1\xe6\x82[##h\xdf"\xd1S\xf2Z2_\x87\x8fr\xd7\n\x0fYC\xcbX\x89\xe8\x84\xf6@5\x88aqDHez\x86\xb9_k\x9f\xc6\x87-#bcL.Dy\xf9,\x07\x18'
        b'i\xb7\x11-\x0e\xa0\x02km\x84h\x8794\xb0#n\x81\xcf\xfcb\xb4\xbd\xf14{\xb8|Yh\x02\xd2\xfa$|Q5\xd66C\x1f\xd5\xeb\xc2\r<\x01\x81_\x9d\xed\x86\x96\xecE\x93>\x9c\xcb1>\xdc\xc4\xc5'
        b'\x18\xb5LN\x91\x94\xcd\x82\x8f:\xf9\xfdN&\xd6?\xc2T\xae.\xf3\xda;\xc7:\xe4\xa1\xe5\x83\xce#Q6\xba\xc9\xc3\xd5\xfb\x9bG{\xabM\xdav\xf7\x06\xbb\xc9\tML+2B\xcbe\xb6\xef\xb0xp\x86H'
        b'\xbd\xe0W\xaa5\xb0\xd5$&\xcb\xee\r\xea\xc2>\xff\x88\xd4\xd6\xf2\xef{,\t\xe3O\x82\x9f\x86*,\xee\xa4I\xd6\x9c]\xea\xa7\x05N\x16\xb7f\x9f\xec\r\x8e\xab\xa0\xac\x8dx_\x19\xeb"\xcdE\xde\xf6\xf9\xe3\x93'
        b"\xbe&\x02\x01\x9a\xe5`z\xb7B<\x9b\xe0z\xb8\xf6w\x87\xfe\xe5\x00\x81}\xb7$\xdaiB\xa1\x9a\xd1uf\x90\x15\x7f5t\x9f;XZo{\xf4\xa5\xad\xf2\x9e\x06RM\x17\xa7<\xc4\xbb\x13'\x94\t?N\x88"
        b'\xce\x12F\xce\x15\x82\x93VkI,\xc9\xfc%\n\xdb\x8e\xf2$\xa4\xe9\xb0\xf6\xf2\xc4c>\x8em(\xb9\x0e\xfd\xaf\xe4]\x17\xd9;<\xa9\xb8\xde\x86\xe1z+1\xd0\x04\xa4kF\x00^\xbc\xd2\xdfcp!\xf2\xfe\xcf'
        b'\xdf\xd2:\xa0\xd7\xef\x96BF]sh\xd8\x03\xd1\xdf\xd7\xf5\x0c\xad\'bn\xdf\xd9;c\x945\xdd\x0c\x8e\xf2\xf7F\xf0/i}\xd9\xacC\xe0\xf6Y\xd4\x94\xdb/s2o\xd9oO6\xc8\x96\xa9\xc9\xd7\x94\xb6"'
        b'.\x8b\x86b\x06\xe4&\x86\xd2\xa0\xbc}\xd3\x88)!;r\xa1$\xd9\x90\xc2\xbe\x890d88\x8fv\xdd\x92=\xd2\tI\x8d08\xf8w\xa7Y\x91\x0eb3\xb2\x83\xc5\xcc\x91\xf1\xd3\xdf\xd2y\x9e\xaa\x9a\xecwG'
        b'\xba(c\x15\x860\xea\x0e{w\xf6\xe8\x9c\xa0\xedC\n\\p\x02X>\x91\x9d\x84\x13\xc5\x05\xf0\xb3\xcc\xc7\\\xef\x12\xc7\x13/\t\n\x90\xa2\xac\xf6U#\xef\\\x98C\x03t\x04\x86l\x15\x88\x1c^-\x0cg\x01l'
        b'\xbf@\r\x18\xb8d\xef\xa0U\xf2}y\x98\x8d\xf4ve\xa8\xb3\xc4\xd5\xd9qV\x8b$y\x94\xc9>\xab\x88\xe3\xa1V:\x06\x06\xfa\xef \xf0\x8b\xc6\xf5\xed\x1e\x16?\xf3\xa7x\xdeVe&9`J%$\x86!\xd6'
        b"\x85\x16\x03\xfe\x94\x14\xbf\xbb\xeb\xc9\x8fj\x98\x98\xf9\x8bf\xd4\xaeK;k\xaf\\K\x01\xa2\xee7\xd5\x15-\xe3\xfeI\xa4<N\x00?\x96\xb7#\x16\xfa\x82?'\xac\xee\x10k+\x06\x96\x19\x8b\xeb\xce\xa5`\xca\x0c\xf3"
        b'\x98a\xfb44[py\x9c\xe5\xbc\xcfa\x81\x9c=\x1ej\xbd\x02\xe9>\xc4\x96\xcc\xaa\xcb\xcauy\xd1\xd1{\xf9\x19\xe6\xcf\xf1\xd5\xb5JJ\n\x00\xe4\xa6k\x87]o\xb7\xfe\xe9J\xd5$W\xc8\xc4\r\xfa\x9ef\x10'
        b'u\xc0\xdf\xd0\\c\x0c\x90\x93_B>\xc1\x02\x1f=\xf2\xb5\xb7\xd4/\xebe\x1b9L,\xa2z$Q\x17p\x84\xf3\x98\x96h?I:\x86\xc5\xd0#m\x12|\x00\x8d\xe5\xdd\x1d\xc6x\xf3"{\x8f\x1f\x94\xe8\xff '
        b'X]\nL\xf2\xba\x94\xcb\xc0\xb7\xab\x9f\xef\xe7\xcc\x1a\xceq3\xdf\n\xc3C6\x88\xf1\x85S\xb993\\[;u5\x9d\x10^@\xa60\x16\xf0\xd2\x9ai\xf2\x8a\xc0Js\xb6\x87\xa6~\xc0\x93\xad\x1b\xe86\xa9`'
        b'\xdc\xa0\x1e\xf7\r\xc2\xee(\xf7\xd9\x8b*~\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__fi'
        b'le__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x03\x00\x08\x01\x03'
        b'\x00\x11\x01'
    ))
